Class: Aws::CodeArtifact::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CodeArtifact::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-codeartifact/client.rb
Overview
An API client for CodeArtifact. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::CodeArtifact::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_external_connection(params = {}) ⇒ Types::AssociateExternalConnectionResult
Adds an existing external connection to a repository.
-
#copy_package_versions(params = {}) ⇒ Types::CopyPackageVersionsResult
Copies package versions from one repository to another repository in the same domain.
-
#create_domain(params = {}) ⇒ Types::CreateDomainResult
Creates a domain.
-
#create_package_group(params = {}) ⇒ Types::CreatePackageGroupResult
Creates a package group.
-
#create_repository(params = {}) ⇒ Types::CreateRepositoryResult
Creates a repository.
-
#delete_domain(params = {}) ⇒ Types::DeleteDomainResult
Deletes a domain.
-
#delete_domain_permissions_policy(params = {}) ⇒ Types::DeleteDomainPermissionsPolicyResult
Deletes the resource policy set on a domain.
-
#delete_package(params = {}) ⇒ Types::DeletePackageResult
Deletes a package and all associated package versions.
-
#delete_package_group(params = {}) ⇒ Types::DeletePackageGroupResult
Deletes a package group.
-
#delete_package_versions(params = {}) ⇒ Types::DeletePackageVersionsResult
Deletes one or more versions of a package.
-
#delete_repository(params = {}) ⇒ Types::DeleteRepositoryResult
Deletes a repository.
-
#delete_repository_permissions_policy(params = {}) ⇒ Types::DeleteRepositoryPermissionsPolicyResult
Deletes the resource policy that is set on a repository.
-
#describe_domain(params = {}) ⇒ Types::DescribeDomainResult
Returns a [DomainDescription] object that contains information about the requested domain.
-
#describe_package(params = {}) ⇒ Types::DescribePackageResult
Returns a [PackageDescription] object that contains information about the requested package.
-
#describe_package_group(params = {}) ⇒ Types::DescribePackageGroupResult
Returns a [PackageGroupDescription] object that contains information about the requested package group.
-
#describe_package_version(params = {}) ⇒ Types::DescribePackageVersionResult
Returns a [PackageVersionDescription] object that contains information about the requested package version.
-
#describe_repository(params = {}) ⇒ Types::DescribeRepositoryResult
Returns a ‘RepositoryDescription` object that contains detailed information about the requested repository.
-
#disassociate_external_connection(params = {}) ⇒ Types::DisassociateExternalConnectionResult
Removes an existing external connection from a repository.
-
#dispose_package_versions(params = {}) ⇒ Types::DisposePackageVersionsResult
Deletes the assets in package versions and sets the package versions’ status to ‘Disposed`.
-
#get_associated_package_group(params = {}) ⇒ Types::GetAssociatedPackageGroupResult
Returns the most closely associated package group to the specified package.
-
#get_authorization_token(params = {}) ⇒ Types::GetAuthorizationTokenResult
Generates a temporary authorization token for accessing repositories in the domain.
-
#get_domain_permissions_policy(params = {}) ⇒ Types::GetDomainPermissionsPolicyResult
Returns the resource policy attached to the specified domain.
-
#get_package_version_asset(params = {}) ⇒ Types::GetPackageVersionAssetResult
Returns an asset (or file) that is in a package.
-
#get_package_version_readme(params = {}) ⇒ Types::GetPackageVersionReadmeResult
Gets the readme file or descriptive text for a package version.
-
#get_repository_endpoint(params = {}) ⇒ Types::GetRepositoryEndpointResult
Returns the endpoint of a repository for a specific package format.
-
#get_repository_permissions_policy(params = {}) ⇒ Types::GetRepositoryPermissionsPolicyResult
Returns the resource policy that is set on a repository.
-
#list_allowed_repositories_for_group(params = {}) ⇒ Types::ListAllowedRepositoriesForGroupResult
Lists the repositories in the added repositories list of the specified restriction type for a package group.
-
#list_associated_packages(params = {}) ⇒ Types::ListAssociatedPackagesResult
Returns a list of packages associated with the requested package group.
-
#list_domains(params = {}) ⇒ Types::ListDomainsResult
Returns a list of [DomainSummary] objects for all domains owned by the Amazon Web Services account that makes this call.
-
#list_package_groups(params = {}) ⇒ Types::ListPackageGroupsResult
Returns a list of package groups in the requested domain.
-
#list_package_version_assets(params = {}) ⇒ Types::ListPackageVersionAssetsResult
Returns a list of [AssetSummary] objects for assets in a package version.
-
#list_package_version_dependencies(params = {}) ⇒ Types::ListPackageVersionDependenciesResult
Returns the direct dependencies for a package version.
-
#list_package_versions(params = {}) ⇒ Types::ListPackageVersionsResult
Returns a list of [PackageVersionSummary] objects for package versions in a repository that match the request parameters.
-
#list_packages(params = {}) ⇒ Types::ListPackagesResult
Returns a list of [PackageSummary] objects for packages in a repository that match the request parameters.
-
#list_repositories(params = {}) ⇒ Types::ListRepositoriesResult
Returns a list of [RepositorySummary] objects.
-
#list_repositories_in_domain(params = {}) ⇒ Types::ListRepositoriesInDomainResult
Returns a list of [RepositorySummary] objects.
-
#list_sub_package_groups(params = {}) ⇒ Types::ListSubPackageGroupsResult
Returns a list of direct children of the specified package group.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResult
Gets information about Amazon Web Services tags for a specified Amazon Resource Name (ARN) in CodeArtifact.
-
#publish_package_version(params = {}) ⇒ Types::PublishPackageVersionResult
Creates a new package version containing one or more assets (or files).
-
#put_domain_permissions_policy(params = {}) ⇒ Types::PutDomainPermissionsPolicyResult
Sets a resource policy on a domain that specifies permissions to access it.
-
#put_package_origin_configuration(params = {}) ⇒ Types::PutPackageOriginConfigurationResult
Sets the package origin configuration for a package.
-
#put_repository_permissions_policy(params = {}) ⇒ Types::PutRepositoryPermissionsPolicyResult
Sets the resource policy on a repository that specifies permissions to access it.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a resource in CodeArtifact.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource in CodeArtifact.
-
#update_package_group(params = {}) ⇒ Types::UpdatePackageGroupResult
Updates a package group.
-
#update_package_group_origin_configuration(params = {}) ⇒ Types::UpdatePackageGroupOriginConfigurationResult
Updates the package origin configuration for a package group.
-
#update_package_versions_status(params = {}) ⇒ Types::UpdatePackageVersionsStatusResult
Updates the status of one or more versions of a package.
-
#update_repository(params = {}) ⇒ Types::UpdateRepositoryResult
Update the properties of a repository.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4064 4065 4066 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 4064 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4067 4068 4069 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 4067 def errors_module Errors end |
Instance Method Details
#associate_external_connection(params = {}) ⇒ Types::AssociateExternalConnectionResult
Adds an existing external connection to a repository. One external connection is allowed per repository.
<note markdown=“1”> A repository can have one or more upstream repositories, or an external connection.
</note>
552 553 554 555 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 552 def associate_external_connection(params = {}, = {}) req = build_request(:associate_external_connection, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 4050 4051 4052 4053 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 4037 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CodeArtifact') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-codeartifact' context[:gem_version] = '1.77.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_package_versions(params = {}) ⇒ Types::CopyPackageVersionsResult
Copies package versions from one repository to another repository in the same domain.
<note markdown=“1”> You must specify ‘versions` or `versionRevisions`. You cannot specify both.
</note>
684 685 686 687 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 684 def copy_package_versions(params = {}, = {}) req = build_request(:copy_package_versions, params) req.send_request() end |
#create_domain(params = {}) ⇒ Types::CreateDomainResult
Creates a domain. CodeArtifact domains make it easier to manage multiple repositories across an organization. You can use a domain to apply permissions across many repositories owned by different Amazon Web Services accounts. An asset is stored only once in a domain, even if it’s in multiple repositories.
Although you can have multiple domains, we recommend a single production domain that contains all published artifacts so that your development teams can find and share packages. You can use a second pre-production domain to test changes to the production domain configuration.
765 766 767 768 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 765 def create_domain(params = {}, = {}) req = build_request(:create_domain, params) req.send_request() end |
#create_package_group(params = {}) ⇒ Types::CreatePackageGroupResult
Creates a package group. For more information about creating package groups, including example CLI commands, see [Create a package group] in the *CodeArtifact User Guide*.
[1]: docs.aws.amazon.com/codeartifact/latest/ug/create-package-group.html
840 841 842 843 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 840 def create_package_group(params = {}, = {}) req = build_request(:create_package_group, params) req.send_request() end |
#create_repository(params = {}) ⇒ Types::CreateRepositoryResult
Creates a repository.
918 919 920 921 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 918 def create_repository(params = {}, = {}) req = build_request(:create_repository, params) req.send_request() end |
#delete_domain(params = {}) ⇒ Types::DeleteDomainResult
Deletes a domain. You cannot delete a domain that contains repositories. If you want to delete a domain with repositories, first delete its repositories.
961 962 963 964 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 961 def delete_domain(params = {}, = {}) req = build_request(:delete_domain, params) req.send_request() end |
#delete_domain_permissions_policy(params = {}) ⇒ Types::DeleteDomainPermissionsPolicyResult
Deletes the resource policy set on a domain.
1003 1004 1005 1006 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1003 def (params = {}, = {}) req = build_request(:delete_domain_permissions_policy, params) req.send_request() end |
#delete_package(params = {}) ⇒ Types::DeletePackageResult
Deletes a package and all associated package versions. A deleted package cannot be restored. To delete one or more package versions, use the [DeletePackageVersions] API.
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_DeletePackageVersions.html
1084 1085 1086 1087 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1084 def delete_package(params = {}, = {}) req = build_request(:delete_package, params) req.send_request() end |
#delete_package_group(params = {}) ⇒ Types::DeletePackageGroupResult
Deletes a package group. Deleting a package group does not delete packages or package versions associated with the package group. When a package group is deleted, the direct child package groups will become children of the package group’s direct parent package group. Therefore, if any of the child groups are inheriting any settings from the parent, those settings could change.
1140 1141 1142 1143 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1140 def delete_package_group(params = {}, = {}) req = build_request(:delete_package_group, params) req.send_request() end |
#delete_package_versions(params = {}) ⇒ Types::DeletePackageVersionsResult
Deletes one or more versions of a package. A deleted package version cannot be restored in your repository. If you want to remove a package version from your repository and be able to restore it later, set its status to ‘Archived`. Archived packages cannot be downloaded from a repository and don’t show up with list package APIs (for example, [ListPackageVersions]), but you can restore them using [UpdatePackageVersionsStatus].
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackageVersions.html [2]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_UpdatePackageVersionsStatus.html
1239 1240 1241 1242 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1239 def delete_package_versions(params = {}, = {}) req = build_request(:delete_package_versions, params) req.send_request() end |
#delete_repository(params = {}) ⇒ Types::DeleteRepositoryResult
Deletes a repository.
1288 1289 1290 1291 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1288 def delete_repository(params = {}, = {}) req = build_request(:delete_repository, params) req.send_request() end |
#delete_repository_permissions_policy(params = {}) ⇒ Types::DeleteRepositoryPermissionsPolicyResult
Deletes the resource policy that is set on a repository. After a resource policy is deleted, the permissions allowed and denied by the deleted policy are removed. The effect of deleting a resource policy might not be immediate.
Use ‘DeleteRepositoryPermissionsPolicy` with caution. After a policy is deleted, Amazon Web Services users, roles, and accounts lose permissions to perform the repository actions granted by the deleted policy.
1344 1345 1346 1347 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1344 def (params = {}, = {}) req = build_request(:delete_repository_permissions_policy, params) req.send_request() end |
#describe_domain(params = {}) ⇒ Types::DescribeDomainResult
Returns a [DomainDescription] object that contains information about the requested domain.
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_DomainDescription.html
1390 1391 1392 1393 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1390 def describe_domain(params = {}, = {}) req = build_request(:describe_domain, params) req.send_request() end |
#describe_package(params = {}) ⇒ Types::DescribePackageResult
Returns a [PackageDescription] object that contains information about the requested package.
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageDescription.html
1471 1472 1473 1474 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1471 def describe_package(params = {}, = {}) req = build_request(:describe_package, params) req.send_request() end |
#describe_package_group(params = {}) ⇒ Types::DescribePackageGroupResult
Returns a [PackageGroupDescription] object that contains information about the requested package group.
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageGroupDescription.html
1527 1528 1529 1530 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1527 def describe_package_group(params = {}, = {}) req = build_request(:describe_package_group, params) req.send_request() end |
#describe_package_version(params = {}) ⇒ Types::DescribePackageVersionResult
Returns a [PackageVersionDescription] object that contains information about the requested package version.
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageVersionDescription.html
1624 1625 1626 1627 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1624 def describe_package_version(params = {}, = {}) req = build_request(:describe_package_version, params) req.send_request() end |
#describe_repository(params = {}) ⇒ Types::DescribeRepositoryResult
Returns a ‘RepositoryDescription` object that contains detailed information about the requested repository.
1674 1675 1676 1677 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1674 def describe_repository(params = {}, = {}) req = build_request(:describe_repository, params) req.send_request() end |
#disassociate_external_connection(params = {}) ⇒ Types::DisassociateExternalConnectionResult
Removes an existing external connection from a repository.
1729 1730 1731 1732 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1729 def disassociate_external_connection(params = {}, = {}) req = build_request(:disassociate_external_connection, params) req.send_request() end |
#dispose_package_versions(params = {}) ⇒ Types::DisposePackageVersionsResult
Deletes the assets in package versions and sets the package versions’ status to ‘Disposed`. A disposed package version cannot be restored in your repository because its assets are deleted.
To view all disposed package versions in a repository, use
- ListPackageVersions][1
-
and set the [status] parameter to
‘Disposed`.
To view information about a disposed package version, use [DescribePackageVersion].
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackageVersions.html [2]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_ListPackageVersions.html#API_ListPackageVersions_RequestSyntax [3]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_DescribePackageVersion.html
1839 1840 1841 1842 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1839 def dispose_package_versions(params = {}, = {}) req = build_request(:dispose_package_versions, params) req.send_request() end |
#get_associated_package_group(params = {}) ⇒ Types::GetAssociatedPackageGroupResult
Returns the most closely associated package group to the specified package. This API does not require that the package exist in any repository in the domain. As such, ‘GetAssociatedPackageGroup` can be used to see which package group’s origin configuration applies to a package before that package is in a repository. This can be helpful to check if public packages are blocked without ingesting them.
For information package group association and matching, see [Package group definition syntax and matching behavior] in the *CodeArtifact User Guide*.
[1]: docs.aws.amazon.com/codeartifact/latest/ug/package-group-definition-syntax-matching-behavior.html
1938 1939 1940 1941 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 1938 def get_associated_package_group(params = {}, = {}) req = build_request(:get_associated_package_group, params) req.send_request() end |
#get_authorization_token(params = {}) ⇒ Types::GetAuthorizationTokenResult
Generates a temporary authorization token for accessing repositories in the domain. This API requires the ‘codeartifact:GetAuthorizationToken` and `sts:GetServiceBearerToken` permissions. For more information about authorization tokens, see [CodeArtifact authentication and tokens].
<note markdown=“1”> CodeArtifact authorization tokens are valid for a period of 12 hours when created with the ‘login` command. You can call `login` periodically to refresh the token. When you create an authorization token with the `GetAuthorizationToken` API, you can set a custom authorization period, up to a maximum of 12 hours, with the `durationSeconds` parameter.
The authorization period begins after `login` or
‘GetAuthorizationToken` is called. If `login` or `GetAuthorizationToken` is called while assuming a role, the token lifetime is independent of the maximum session duration of the role. For example, if you call `sts assume-role` and specify a session duration of 15 minutes, then generate a CodeArtifact authorization token, the token will be valid for the full authorization period even though this is longer than the 15-minute session duration.
See [Using IAM Roles][2] for more information on controlling session
duration.
</note>
[1]: docs.aws.amazon.com/codeartifact/latest/ug/tokens-authentication.html [2]: docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html
2012 2013 2014 2015 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 2012 def (params = {}, = {}) req = build_request(:get_authorization_token, params) req.send_request() end |
#get_domain_permissions_policy(params = {}) ⇒ Types::GetDomainPermissionsPolicyResult
Returns the resource policy attached to the specified domain.
<note markdown=“1”> The policy is a resource-based policy, not an identity-based policy. For more information, see [Identity-based policies and resource-based policies ][1] in the *IAM User Guide*.
</note>
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_identity-vs-resource.html
2057 2058 2059 2060 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 2057 def (params = {}, = {}) req = build_request(:get_domain_permissions_policy, params) req.send_request() end |
#get_package_version_asset(params = {}) ⇒ Types::GetPackageVersionAssetResult
Returns an asset (or file) that is in a package. For example, for a Maven package version, use ‘GetPackageVersionAsset` to download a `JAR` file, a `POM` file, or any other assets in the package version.
2153 2154 2155 2156 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 2153 def get_package_version_asset(params = {}, = {}, &block) req = build_request(:get_package_version_asset, params) req.send_request(, &block) end |
#get_package_version_readme(params = {}) ⇒ Types::GetPackageVersionReadmeResult
Gets the readme file or descriptive text for a package version.
The returned text might contain formatting. For example, it might contain formatting for Markdown or reStructuredText.
2246 2247 2248 2249 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 2246 def get_package_version_readme(params = {}, = {}) req = build_request(:get_package_version_readme, params) req.send_request() end |
#get_repository_endpoint(params = {}) ⇒ Types::GetRepositoryEndpointResult
Returns the endpoint of a repository for a specific package format. A repository has one endpoint for each package format:
-
‘cargo`
-
‘generic`
-
‘maven`
-
‘npm`
-
‘nuget`
-
‘pypi`
-
‘ruby`
-
‘swift`
2310 2311 2312 2313 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 2310 def get_repository_endpoint(params = {}, = {}) req = build_request(:get_repository_endpoint, params) req.send_request() end |
#get_repository_permissions_policy(params = {}) ⇒ Types::GetRepositoryPermissionsPolicyResult
Returns the resource policy that is set on a repository.
2351 2352 2353 2354 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 2351 def (params = {}, = {}) req = build_request(:get_repository_permissions_policy, params) req.send_request() end |
#list_allowed_repositories_for_group(params = {}) ⇒ Types::ListAllowedRepositoriesForGroupResult
Lists the repositories in the added repositories list of the specified restriction type for a package group. For more information about restriction types and added repository lists, see [Package group origin controls] in the *CodeArtifact User Guide*.
[1]: docs.aws.amazon.com/codeartifact/latest/ug/package-group-origin-controls.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2417 2418 2419 2420 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 2417 def list_allowed_repositories_for_group(params = {}, = {}) req = build_request(:list_allowed_repositories_for_group, params) req.send_request() end |
#list_associated_packages(params = {}) ⇒ Types::ListAssociatedPackagesResult
Returns a list of packages associated with the requested package group. For information package group association and matching, see
- Package group definition syntax and matching behavior][1
-
in the
*CodeArtifact User Guide*.
[1]: docs.aws.amazon.com/codeartifact/latest/ug/package-group-definition-syntax-matching-behavior.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2487 2488 2489 2490 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 2487 def list_associated_packages(params = {}, = {}) req = build_request(:list_associated_packages, params) req.send_request() end |
#list_domains(params = {}) ⇒ Types::ListDomainsResult
Returns a list of [DomainSummary] objects for all domains owned by the Amazon Web Services account that makes this call. Each returned ‘DomainSummary` object contains information about a domain.
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageVersionDescription.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2537 2538 2539 2540 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 2537 def list_domains(params = {}, = {}) req = build_request(:list_domains, params) req.send_request() end |
#list_package_groups(params = {}) ⇒ Types::ListPackageGroupsResult
Returns a list of package groups in the requested domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2605 2606 2607 2608 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 2605 def list_package_groups(params = {}, = {}) req = build_request(:list_package_groups, params) req.send_request() end |
#list_package_version_assets(params = {}) ⇒ Types::ListPackageVersionAssetsResult
Returns a list of [AssetSummary] objects for assets in a package version.
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_AssetSummary.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2718 2719 2720 2721 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 2718 def list_package_version_assets(params = {}, = {}) req = build_request(:list_package_version_assets, params) req.send_request() end |
#list_package_version_dependencies(params = {}) ⇒ Types::ListPackageVersionDependenciesResult
Returns the direct dependencies for a package version. The dependencies are returned as [PackageDependency] objects. CodeArtifact extracts the dependencies for a package version from the metadata file for the package format (for example, the ‘package.json` file for npm packages and the `pom.xml` file for Maven). Any package version dependencies that are not listed in the configuration file are not returned.
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageDependency.html
2824 2825 2826 2827 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 2824 def list_package_version_dependencies(params = {}, = {}) req = build_request(:list_package_version_dependencies, params) req.send_request() end |
#list_package_versions(params = {}) ⇒ Types::ListPackageVersionsResult
Returns a list of [PackageVersionSummary] objects for package versions in a repository that match the request parameters. Package versions of all statuses will be returned by default when calling ‘list-package-versions` with no `–status` parameter.
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageVersionSummary.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2947 2948 2949 2950 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 2947 def list_package_versions(params = {}, = {}) req = build_request(:list_package_versions, params) req.send_request() end |
#list_packages(params = {}) ⇒ Types::ListPackagesResult
Returns a list of [PackageSummary] objects for packages in a repository that match the request parameters.
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_PackageSummary.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3060 3061 3062 3063 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3060 def list_packages(params = {}, = {}) req = build_request(:list_packages, params) req.send_request() end |
#list_repositories(params = {}) ⇒ Types::ListRepositoriesResult
Returns a list of [RepositorySummary] objects. Each ‘RepositorySummary` contains information about a repository in the specified Amazon Web Services account and that matches the input parameters.
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_RepositorySummary.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3117 3118 3119 3120 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3117 def list_repositories(params = {}, = {}) req = build_request(:list_repositories, params) req.send_request() end |
#list_repositories_in_domain(params = {}) ⇒ Types::ListRepositoriesInDomainResult
Returns a list of [RepositorySummary] objects. Each ‘RepositorySummary` contains information about a repository in the specified domain and that matches the input parameters.
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_RepositorySummary.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3188 3189 3190 3191 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3188 def list_repositories_in_domain(params = {}, = {}) req = build_request(:list_repositories_in_domain, params) req.send_request() end |
#list_sub_package_groups(params = {}) ⇒ Types::ListSubPackageGroupsResult
Returns a list of direct children of the specified package group.
For information package group hierarchy, see [Package group definition syntax and matching behavior] in the *CodeArtifact User Guide*.
[1]: docs.aws.amazon.com/codeartifact/latest/ug/package-group-definition-syntax-matching-behavior.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3263 3264 3265 3266 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3263 def list_sub_package_groups(params = {}, = {}) req = build_request(:list_sub_package_groups, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResult
Gets information about Amazon Web Services tags for a specified Amazon Resource Name (ARN) in CodeArtifact.
3294 3295 3296 3297 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3294 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#publish_package_version(params = {}) ⇒ Types::PublishPackageVersionResult
Creates a new package version containing one or more assets (or files).
The ‘unfinished` flag can be used to keep the package version in the `Unfinished` state until all of its assets have been uploaded (see
- Package version status][1
-
in the *CodeArtifact user guide*). To set
the package version’s status to ‘Published`, omit the `unfinished` flag when uploading the final asset, or set the status using [UpdatePackageVersionStatus]. Once a package version’s status is set to `Published`, it cannot change back to `Unfinished`.
<note markdown=“1”> Only generic packages can be published using this API. For more information, see [Using generic packages] in the *CodeArtifact User Guide*.
</note>
[1]: docs.aws.amazon.com/codeartifact/latest/ug/packages-overview.html#package-version-status.html#package-version-status [2]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_UpdatePackageVersionsStatus.html [3]: docs.aws.amazon.com/codeartifact/latest/ug/using-generic.html
3424 3425 3426 3427 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3424 def publish_package_version(params = {}, = {}) req = build_request(:publish_package_version, params) req.send_request() end |
#put_domain_permissions_policy(params = {}) ⇒ Types::PutDomainPermissionsPolicyResult
Sets a resource policy on a domain that specifies permissions to access it.
When you call ‘PutDomainPermissionsPolicy`, the resource policy on the domain is ignored when evaluting permissions. This ensures that the owner of a domain cannot lock themselves out of the domain, which would prevent them from being able to update the resource policy.
3476 3477 3478 3479 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3476 def (params = {}, = {}) req = build_request(:put_domain_permissions_policy, params) req.send_request() end |
#put_package_origin_configuration(params = {}) ⇒ Types::PutPackageOriginConfigurationResult
Sets the package origin configuration for a package.
The package origin configuration determines how new versions of a package can be added to a repository. You can allow or block direct publishing of new package versions, or ingestion and retaining of new package versions from an external connection or upstream source. For more information about package origin controls and configuration, see
- Editing package origin controls][1
-
in the *CodeArtifact User Guide*.
‘PutPackageOriginConfiguration` can be called on a package that doesn’t yet exist in the repository. When called on a package that does not exist, a package is created in the repository with no versions and the requested restrictions are set on the package. This can be used to preemptively block ingesting or retaining any versions from external connections or upstream repositories, or to block publishing any versions of the package into the repository before connecting any package managers or publishers to the repository.
[1]: docs.aws.amazon.com/codeartifact/latest/ug/package-origin-controls.html
3577 3578 3579 3580 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3577 def put_package_origin_configuration(params = {}, = {}) req = build_request(:put_package_origin_configuration, params) req.send_request() end |
#put_repository_permissions_policy(params = {}) ⇒ Types::PutRepositoryPermissionsPolicyResult
Sets the resource policy on a repository that specifies permissions to access it.
When you call ‘PutRepositoryPermissionsPolicy`, the resource policy on the repository is ignored when evaluting permissions. This ensures that the owner of a repository cannot lock themselves out of the repository, which would prevent them from being able to update the resource policy.
3636 3637 3638 3639 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3636 def (params = {}, = {}) req = build_request(:put_repository_permissions_policy, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for a resource in CodeArtifact.
3668 3669 3670 3671 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3668 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a resource in CodeArtifact.
3695 3696 3697 3698 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3695 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_package_group(params = {}) ⇒ Types::UpdatePackageGroupResult
Updates a package group. This API cannot be used to update a package group’s origin configuration or pattern. To update a package group’s origin configuration, use [UpdatePackageGroupOriginConfiguration].
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_UpdatePackageGroupOriginConfiguration.html
3761 3762 3763 3764 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3761 def update_package_group(params = {}, = {}) req = build_request(:update_package_group, params) req.send_request() end |
#update_package_group_origin_configuration(params = {}) ⇒ Types::UpdatePackageGroupOriginConfigurationResult
Updates the package origin configuration for a package group.
The package origin configuration determines how new versions of a package can be added to a repository. You can allow or block direct publishing of new package versions, or ingestion and retaining of new package versions from an external connection or upstream source. For more information about package group origin controls and configuration, see [Package group origin controls] in the *CodeArtifact User Guide*.
[1]: docs.aws.amazon.com/codeartifact/latest/ug/package-group-origin-controls.html
3858 3859 3860 3861 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3858 def update_package_group_origin_configuration(params = {}, = {}) req = build_request(:update_package_group_origin_configuration, params) req.send_request() end |
#update_package_versions_status(params = {}) ⇒ Types::UpdatePackageVersionsStatusResult
Updates the status of one or more versions of a package. Using ‘UpdatePackageVersionsStatus`, you can update the status of package versions to `Archived`, `Published`, or `Unlisted`. To set the status of a package version to `Disposed`, use [DisposePackageVersions].
[1]: docs.aws.amazon.com/codeartifact/latest/APIReference/API_DisposePackageVersions.html
3959 3960 3961 3962 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 3959 def update_package_versions_status(params = {}, = {}) req = build_request(:update_package_versions_status, params) req.send_request() end |
#update_repository(params = {}) ⇒ Types::UpdateRepositoryResult
Update the properties of a repository.
4028 4029 4030 4031 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 4028 def update_repository(params = {}, = {}) req = build_request(:update_repository, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4057 4058 4059 |
# File 'lib/aws-sdk-codeartifact/client.rb', line 4057 def waiter_names [] end |