Class: Aws::CodeArtifact::Types::PackageOriginRestrictions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codeartifact/types.rb

Overview

Details about the origin restrictions set on the package. The package origin restrictions determine how new versions of a package can be added to a specific repository.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#publishString

The package origin configuration that determines if new versions of the package can be published directly to the repository.



3225
3226
3227
3228
3229
3230
# File 'lib/aws-sdk-codeartifact/types.rb', line 3225

class PackageOriginRestrictions < Struct.new(
  :publish,
  :upstream)
  SENSITIVE = []
  include Aws::Structure
end

#upstreamString

The package origin configuration that determines if new versions of the package can be added to the repository from an external connection or upstream source.



3225
3226
3227
3228
3229
3230
# File 'lib/aws-sdk-codeartifact/types.rb', line 3225

class PackageOriginRestrictions < Struct.new(
  :publish,
  :upstream)
  SENSITIVE = []
  include Aws::Structure
end